aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xbin/makepkgdb.pl10
1 files changed, 5 insertions, 5 deletions
diff --git a/bin/makepkgdb.pl b/bin/makepkgdb.pl
index 31838d3..6591d2f 100755
--- a/bin/makepkgdb.pl
+++ b/bin/makepkgdb.pl
@@ -22,8 +22,8 @@
### configurables:
@pkglists = (
- '/data/mirrors/slackware/slackware64-14.2/PACKAGES.TXT',
- '/data/mirrors/slackware/slackware64-14.2/extra/PACKAGES.TXT',
+ '/data/mirrors/slackware/slackware64-15.0/PACKAGES.TXT',
+ '/data/mirrors/slackware/slackware64-15.0/extra/PACKAGES.TXT',
);
# ...the above list could have included pasture and testing, but
@@ -31,9 +31,9 @@
# pasture and testing installed (we don't right now).
# these 2 are copies of /var/log/packages and /var/log/scripts from
-# a full install of 14.2, with no 3rd-party packages added:
-$pkgdir = "/home/urchlay/var.log/packages";
-$scriptsdir = "/home/urchlay/var.log/scripts";
+# a full install of 15.0, with no 3rd-party packages added:
+$pkgdir = "/home/slackfacts/var.log/packages";
+$scriptsdir = "/home/slackfacts/var.log/scripts";
### end configurables.